%
%  SCRIPT: example1
%
%  This example shows the basic usage of HyBR on
%  some sample test data from Regularization Tools.
%
%  References: 
%  [1] J. Chung, J. Nagy and D. O'Leary, "A Weighted GCV Method
%      for Lanczos Hybrid Regularization", submitted, Feb., 2007.
%  [2] P.C. Hansen, "Regularization Tools: A Matlab package for analysis
%      and solution of discrete ill-posed problems", 
%      Numerical Algorithms, 6 (1994), pp. 1-35.
%      http://www2.imm.dtu.dk/~pch/Regutools
%
%  J. Chung and J. Nagy, March 2007
%

%------------------------------------------------------------------------
%
% The first example is the "phillips" test problem from 
% Regularization Tools [2].
disp(' ')
disp('Press any key to see results of phillips test problem')
pause
disp('(see Figure 1)')
%
%   Generate Test Problem (truth data)
[A, b_true, x_true] = phillips(256);
%
%   Add white noise to get b = A*x_true + N
N = WhiteNoise(b_true);
b = b_true + N;
%
%   Use HyBR with default settings to solve
[x, output] = HyBR(A, b);
%
%   Display results
figure(1), clf
subplot(2,2,1)
  plot(b_true, 'LineWidth', 2)
  axis([1,256,-0.25,2.25])
  title('True data, A*x')
subplot(2,2,2)
  plot(b, 'LineWidth', 2)
  axis([1,256,-0.25,2.25])
  title('Noisy data, b = A*x + N')
subplot(2,2,3)
  plot(x_true, 'LineWidth', 2)
  axis([1,256,-0.2,0.6])
  title('True solution, x')
subplot(2,2,4)
  plot(x, 'LineWidth', 2)
  axis([1,256,-0.2,0.6])
  title(sprintf('HyBR computed solution, %d iters, exit %d', output.iterations, output.flag))
  
%------------------------------------------------------------------------
%
% The second example is the "shaw" test problem from 
% Regularization Tools [2].
disp(' ')
disp('Press any key to see results of shaw test problem')
pause
disp('(see Figure 2).')
%
%   Generate Test Problem (truth data)
[A, b_true, x_true] = shaw(256);
%
%   Add white noise to get b = A*x_true + N
N = WhiteNoise(b_true);
b = b_true + N;
%
%   Use HyBR with default settings to solve
[x, output] = HyBR(A, b);
%
%   Display results
figure(2), clf
subplot(2,2,1)
  plot(b_true, 'LineWidth', 2)
  axis([1,256,0,4])
  title('True data, A*x')
subplot(2,2,2)
  plot(b, 'LineWidth', 2)
  axis([1,256,0,4])
  title('Noisy data, b = A*x + N')
subplot(2,2,3)
  plot(x_true, 'LineWidth', 2)
  axis([1,256,0,2.25])
  title('True solution, x')
subplot(2,2,4)
  plot(x, 'LineWidth', 2)
  axis([1,256,0,2.25])
  title(sprintf('HyBR computed solution, %d iters, exit %d', output.iterations, output.flag))
  
%------------------------------------------------------------------------
%
% The third example is the "deriv2" test problem from 
% Regularization Tools [2].
disp(' ')
disp('Press any key to see results of deriv2 test problem')
pause
disp('(see Figure 3).')
%
%   Generate Test Problem (truth data)
[A, b_true, x_true] = deriv2(256);
%
%   Add white noise to get b = A*x_true + N
N = WhiteNoise(b_true);
b = b_true + N;
%
%   Use HyBR with default settings to solve
[x, output] = HyBR(A, b);
%
%   Display results
figure(3), clf
subplot(2,2,1)
  plot(b_true, 'LineWidth', 2)
  title('True data, A*x')
subplot(2,2,2)
  plot(b, 'LineWidth', 2)
  title('Noisy data, b = A*x + N')
subplot(2,2,3)
  plot(x_true, 'LineWidth', 2)
  title('True solution, x')
subplot(2,2,4)
  plot(x, 'LineWidth', 2)
  title(sprintf('HyBR computed solution, %d iters, exit %d', output.iterations, output.flag))
  
%------------------------------------------------------------------------
%
% The fourth example is the "baart" test problem from 
% Regularization Tools [2].
disp(' ')
disp('Press any key to see results of baart test problem')
pause
disp('(see Figure 4).')
%
%   Generate Test Problem (truth data)
[A, b_true, x_true] = baart(256);
%
%   Add white noise to get b = A*x_true + N
N = WhiteNoise(b_true);
b = b_true + N;
%
%   Use HyBR with default settings to solve
[x, output] = HyBR(A, b);
%
%   Display results
figure(4), clf
subplot(2,2,1)
  plot(b_true, 'LineWidth', 2)
  title('True data, A*x')
subplot(2,2,2)
  plot(b, 'LineWidth', 2)
  title('Noisy data, b = A*x + N')
subplot(2,2,3)
  plot(x_true, 'LineWidth', 2)
  title('True solution, x')
subplot(2,2,4)
  plot(x, 'LineWidth', 2)
  title(sprintf('HyBR computed solution, %d iters, exit %d', output.iterations, output.flag))
  
%------------------------------------------------------------------------
%
% The fifth example is the "heat" test problem from 
% Regularization Tools [2].
disp(' ')
disp('Press any key to see results of heat test problem')
pause
disp('(see Figure 5).')
%
%   Generate Test Problem (truth data)
[A, b_true, x_true] = heat(256);
%
%   Add white noise to get b = A*x_true + N
N = WhiteNoise(b_true);
b = b_true + N;
%
%   Use HyBR with default settings to solve
[x, output] = HyBR(A, b);
%
%   Display results
figure(5), clf
subplot(2,2,1)
  plot(b_true, 'LineWidth', 2)
  axis([1,256,-0.02,0.1])
  title('True data, A*x')
subplot(2,2,2)
  plot(b, 'LineWidth', 2)
  axis([1,256,-0.02,0.1])
  title('Noisy data, b = A*x + N')
subplot(2,2,3)
  plot(x_true, 'LineWidth', 2)
  axis([1,256,-0.25,1.25])
  title('True solution, x')
subplot(2,2,4)
  plot(x, 'LineWidth', 2)
  axis([1,256,-0.25,1.25])
  title(sprintf('HyBR computed solution, %d iters, exit %d', output.iterations, output.flag))
